@@ -1,9 +1,10 @@
-import json
+import urllib
+import urllib2
+
+import json 
 
-from django.utils.six.moves.urllib.parse import urlencode
-from django.utils.six.moves.urllib.request import urlopen
 from django.core.management.base import CommandError
-
+from django.conf import settings
 
 def call(method, data, post=False):
     """
@@ -14,12 +15,12 @@ def call(method, data, post=False):
     if post:
         # POST request
         url += "/"
-        data = urlencode(data)
+        data = urllib.urlencode(data)
     else:
         # GET request
-        url += "?%s" % urlencode(data)
+        url += "?%s" % urllib.urlencode(data)
         data = ''
-    res = json.load(urlopen(url, data))
+    res = json.load(urllib2.urlopen(url, data))
     if not res['succeeded']:
         raise CommandError("'%s' failed: %s\nData: %s" % (method, res['code'], data))
     return res['message']
