@@ -1,6 +1,5 @@
-from __future__ import print_function
-
 import json
+
 from optparse import make_option
 
 from django.core.management.base import NoArgsCommand, CommandError
@@ -28,8 +27,8 @@ class Command(NoArgsCommand):
         filter_ = options.get('filter')
         exclude = options.get('exclude')
 
-        # Get a list of all forums for an API key. Each API key can have
-        # multiple forums associated. This application only supports the one
+        # Get a list of all forums for an API key. Each API key can have 
+        # multiple forums associated. This application only supports the one 
         # set in the DISQUS_WEBSITE_SHORTNAME variable
         forum_list = client.get_forum_list(user_api_key=settings.DISQUS_API_KEY)
         try:
@@ -56,4 +55,4 @@ class Command(NoArgsCommand):
             else:
                 start += step
                 posts.append(new_posts)
-        print(json.dumps(posts, indent=indent))
+        print json.dumps(posts, indent=indent)
